@@ -6,9 +6,8 @@ import logging
 logging.basicConfig(level=logging.DEBUG)
 
 import sys; sys.path.append('../')
-import formbuild.helpers
+import formbuild
 
 doctest.testfile('../doc/source/manual.rst', optionflags=doctest.ELLIPSIS)
-doctest.testmod(formbuild.helpers)
-
+doctest.testmod(formbuild)
 
